## RiskyStarterPack

A starter pack containing most of the mods used in hosts. This is meant to be a baseline that you can expand/modify as needed to get your ideal hosting setup.

## Installation

**Skip this if you're just trying to join a host.**

1. Click the Manual Download button on this page, extract RiskyStarterPack.r2z from the .zip file, and place it somewhere that's easy to find.
2. Install [r2modman](https://thunderstore.io/package/ebkr/r2modman/).
3. Open up r2modman, and select Risk of Rain 2.
	- Make sure you didn't accidentally select Risk of Rain 2 Dedicated server.
4. In r2modman, click Import / Update -> Import new profile -> From file -> select RiskyStarterPack.r2z
	- Feel free to rename the profile to whatever you want.
	- Update mods if needed.
	
## Hosting

1. Get your sharable profile code by going to r2modman -> Settings -> Profile -> Export profile as code.
	- Profile codes only last a few hours, so you'll need to get a new one every time you host.
2. Get your sharable lobby code by going to RoR2's Multiplayer menu and clicking **Copy Lobby to Clipboard** on the right side of the screen.

## Joining Hosts

1. In r2modman, click Import / Update -> Import new profile -> From code, and paste the host's profile code.
	- Make sure you **don't** update any mods or else you'll get version mismatch errors.
2. Copy the host's lobby code, then go to RoR2's Multiplayer menu and click **Join Clipboard Lobby**.

## Admin Commands and Other Info

- TooManyFriends is installed, with max players set to 16.
- DropInMultiplayer is installed, so people can join at any time.
- DebugToolkit
	- Adds admin console commands. Check the [mod page](https://thunderstore.io/package/IHarbHD/DebugToolkit/) for more info.
- MidRunArtifacts
	- Enable/Disable artifacts mid-run by using the console commands mra_enable/mra_disable
- ItemBlacklist
	- Allows items/equipments to be blacklisted in the lobby.
	
## Mods you might want to disable depending on setup

- TeammateRevival
	- If you don't want reviving, disable this.
	
- YEET
	- If you don't want players dropping items, disable this.
	
- DoshDrop
	- If you don't want players dropping money, disable this.
	
- BetterCommandArtifact
	- Limits Command selections to 3 choices.
	- Disable this if you want Vanilla Command.
	- Artifact of Potential and CommandPotential add this as a standalone artifact, but both mods have problems that prevent them from being used.
		- Artifact of Potential freezes the game every time something drops.
		- CommandPotential breaks YEET, but is otherwise fine aside from that.
		
- BiggerBazaar
	- Locked behind Bazaar Artifact.
	- Probably needs extra configuration for prices/item rarities/etc.
	
- Alien Hominid (Disabled by default)
	- He plays fine and a lot of hosts run him, can just enable without much issue.
	
- Regigigas (Disabled by default)
	- A popular choice when aiming for crazy setups.
	
- Potmobile + Hauler (Disabled by default)
	- Good for crazy setups.
	
- PlayableTemplar (Disabled by default)
	- Code is questionable. Enable if you have people that like it.
	
- AccurateEnemies
	- Disable this if you're having framerate problems, since it adds extra prediction calculations whenever enemies fire.
	- Alternatively, if you want a hardmode setup, go to the config and remove the elite-only restriction.
	
- ItemStats
	- If you plan to use BetterUI, disable this since the functionality overlaps.
	
- Forgotten Relics
	- A lot of the mod's content is disabled due to being kinda iffy. If you're like to play with that content, re-enable it in the config.
	
- Cooler Mithrix (Disabled by default)
	- Removes the ramps from Mithrix's arena and brings back his unused throne spawn animation. Enable this if you want a bit more of a challenge.

## Recommended Ruleset

You'll need to do lots of experimentation and configuration to find a setup that works best for you, but here's some general things that people do.

- Disable Lobby Votes.

- Artifacts:
	- Artifact of the King
	- Origination
	- Primacy
	- Conformity (personal preference)
		- Can be configured to only remove Scrappers if you still want Printers.
	- Sacrifice (when playercount is high)
		- This is used because interactable spam lags the game at high player counts, and it often ends up with stacked players buying out the map too fast for others to catch up.
		- Recommended to enable Bazaar Artifact or enable Command (limited to 3 choices with BetterCommand) or else players will be at the mercy of RNG.
			- Could argue for limiting choices to 2.
	
- Item Blacklist:
	- Items:
		- Lost Seer's Lens
		- Regenerating Scrap
		- Defiant Gouge
		- Focused Convergence
		- Mercurial Rachis
		- Eulogy Zero
		
		- Charon's Obol (Unused)
		- Dead Man's Hand (Unused)

	- Equipment:
		- Glowing Meteorite
		- Helfire Tincture
		- Effigy of Grief
		
	*This is the bare minimum that should be blacklisted, and is included in the default ItemBlacklist.cfg file. Consider adding useless items to the blacklist, or certain money generation items if playing Bazaar or without Sacrifice.*

## Full Modlist

<details>

- Core:
	- TooManyFriends
	- DropInMultiplayer
	- DebugToolkit
	- RulebookUnlocker
	- ScrollableLobbyUI
	- MidRunArtifacts
	- RiskOfWaiting
	- No Item Pick Up On Collision
	- RealerCheatUnlocks (client-side, **disabled by default**)
	- Videogame Mod 2 Unofficial (SS2U)

- Major Overhauls:
	- RiskyMod
		- Most hosts just use RiskyMod on default settings.
			- If you plan to install other Vanilla balance mods, make sure you disable conflicting features in the RiskyMod config so that the game doesn't break.
		- Reworks Acrid to be closer to RoR1 where he's based around stacking multiple sources of DoT. If you want Vanilla Acrid, go to RiskyMod_Survivors.cfg and disable his changes.
	- EliteReworks
	- TeammateRevival
		- Config has been modified to make it a bit harder to revive compared to the default settings.

- Gameplay:
	- AI Blacklist
		- Configured to be stricter than Vanilla. Vengeance should be somewhat playable.
	- MoreSacrificeInteractables
	- NoVoidFieldsInteractables
		- This prevents equipment barrel spam when using MoreSacrificeInteractables.
	- GupLimiter
	- Admiral (Configured for RiskyMod compat)
	- Sacrifice Tweaks
	- BiggerBazaar
		- Only enabled when using ZetArtifacts' Bazaar artifact.
		- Default config has been changed to allow 5 purchases for each player.
		- Prices and stuff likely need configuration.
	- ZetSizeController
		- Configured to only make Elites larger.
	- BetterCommandArtifact
	- YEET (Item dropping)
	- AccurateEnemies
	- DroneMeld
	- DoshDrop
	- Cooler Mithrix (**disabled by default**)
	- XiConstructFix
	- AlignRexHurtbox
	- BellTowerNerf (for ForgottenRelics)

- QoL:
	- Engi M1 Autofire
	- ChatboxEdit
	- MountainCount
	- SunDimmer
	- SkipIntro
	- AutoSkipCredits
	- Actually Faster
	- NoBazaarKickout
	- SeerPing
	- ShowDeathCause
	- LobbyVotesSave
	- Greentext
	- ItemCounters
	- ItemStats (**DISABLE IF USING BETTERUI**)
	- SurvivorSortOrder
		- Configured to prevent modded characters from mixing in with Vanilla characters.
	- PrintToInventory
	- SafeTravelsInSkybox

- Fixes:
	- ModdedPrismaticTrials
	- CurseCatcher
	- ModdedCharEclipseFix
	- NoVoidsentProcOnNewt
	- EnigmaBlacklist
	- CommandDropletFix
	- GiantParticleFix
	- FixGenesisLoopConsoleSpam
	- PizzaClientLagFix

- Artifacts:
	- Risky Artifacts
	- Artifact of the King Reborn
	- ZetArtifacts
		- Disabled some artifacts, enabled Bazaar artifact.
		- Feel free to re-enable artifacts.

- Survivors:
	- Heretic
	- Enforcer + Nemesis Enforcer
	- HAN-D
	- Chef
	- Sniper
	- Miner
	- Tesla Trooper + Desolator
	- Rocket
	- Deputy
	- Pathfinder
	- Paladin (with PaladinHealthTweak)
	- Regigias (disabled by default)
	- Potmobile + Hauler (disabled by default)
	- Nemesis Commando + Executioner + Chirr + Cyborg + Pyro (SS2U)
	- PlayableTemplar (disabled by default since it might be buggy/laggy)
	- Driver
	- Arsonist
	- Ravager

- Skills:
	- Bandit Dynamite Toss
	- Commando Grenade Cooking
	- FastArtificerBolts
	- Joker Mode

- Items:
	- QueenGlandBuff
	- StandaloneAncientScepter
	- DroneRepairKit
	- StormyItems
		- Abyssal Talon and Charged Urchin disabled.
	- ClassicItemsReturns
	- Videogame Mod 2 Unofficial (SS2U)

- Enemies:
	- Clay Men
	- Archaic Wisp
	- Ancient Wisp
	- Direseeker
	- Blighted Elites
	- Steel Mechorilla
	- StadiaJungleBoss

- Skins:
	- Helot (Commando, scrapped SotV skin)
	- Thy Providence (Paladin)
	- Tink29 HAN-D (HAN-D)
	- Regirock/Registeel/Regiice (Regigigas)
	
- Stages:
	- Fogbound Lagoon
	- Slumbering Satellite (Forgotten Relics)
	
</details>

## Other Recommended Mods

<details>

- [EnemiesWithItems](https://thunderstore.io/package/Anreol/EnemiesWithItems/)
	- Usually used with Bazaar (no purchase limit) and FW artifacts for crazy setups.
	- Requires LOTS of configuration to make it play well. You'll need to look through your item list and manually choose which items to keep/blacklist.
		- As a general rule of thumb, anything that scales off of base damage should be blacklisted (ex. Bleed, Shurikens)
- [StageAesthetic](https://thunderstore.io/package/HIFU/StageAesthetic/)
	- Check variants to see which ones you want to keep/disable. There's some really good looking ones, and then there's some really ugly ones.
- [GestureEnigma](https://thunderstore.io/package/Moffein/GestureEnigma/)
	- Depends on whether the people you're playing with want Gesture or not.
- [Evolution Config](https://thunderstore.io/package/Moffein/Evolution_Config/)
	- Evolution rulesets will probably need further AI Blacklist config edits.
- [RiskOfRuina](https://thunderstore.io/package/Moonlol/UnofficialRiskOfRuina/)
	- Disable character music in config.
	- Some hosts rebalance Red Mist's ego meter, but I don't know the specifics.
- [BadassEmotes](https://thunderstore.io/package/MetrosexualFruitcake/BadAssEmotes/)
	- Increases modpack size by a few hundred mb, if that's a concern.
	- Also check out the other EmoteAPI emote mods on ThunderStore!
	
</details>

## Changelog

<details>

- `1.8.1`
	- Ravager
		- Remembered to include config.
			- ForceUnlock: True
			- Utility Deletes Allied Projectiles: False
			
		*As of Ravager 1.2.4 his Utilty skills don't work online, but I'm banking on it being fixed in a future update.*

- `1.8.0`
	- Replaced RulebookUnlocker with ItemBlacklist.
		- Removed LobbyVoteSave due to conflicting with this.
		- Default Blacklist:
			- Items:
				- Lost Seer's Lens
				- Regenerating Scrap
				- Defiant Gouge
				- Focused Convergence
				- Mercurial Rachis
				- Eulogy Zero
				
				- Charon's Obol (Unused)
				- Dead Man's Hand (Unused)
			
			- Equipment:
				- Glowing Meteorite
				- Helfire Tincture
				- Effigy of Grief
			
	*This should fix the issue with newer hosts not knowing which items to blacklist. There's more items that are worth blacklisting than these, but this should be the bare minimum that should be blacklisted.*

- `1.7.0`
	- Added Ravager.
	- Added PizzaClientLagFix.

- `1.6.4`
	- Updated default AI Equipment Blacklist.

- `1.6.3`
	- Added FixGenesisLoopConsoleSpam

- `1.6.2`
	- Removed HopooHANDSkin since it's now a part of HAN-D.

- `1.6.1`
	- ZetArtifacts
		- Enabled Accumulation and Sanction.
		
		*I have no clue why these were disabled in the first place.*

- `1.6.0`
	- Replaced GoldChestForAll with StadiaJungleBoss.
	- Updated SS2U, has a bunch of items now!
	- Hid misc section of RulebookUnlocker.
	- Added Alien Hominid (Disabled by default)
	- AI Blacklist
		- Vengeance Blacklist
			- Added CIR Permafrost
			- Added CIR Thallium
			
- `1.5.0`
	- Added Arsonist.

- `1.4.10`
	- Reset QueenGlandBuff config due to the new update.

- `1.4.9`
	- Added BellTowerNerf.

- `1.4.8`
	- Added Registeel/Regirock skins for Regigigas.

- `1.4.7`
	- Updated Regigigas Config to use the boss nerf.
	- Added Joker Mode.
	- Added Regirock skin for Regigigas.
	- Added Seraph skin for Void Fiend.
	- Added Tink29 HAN-D skin.
	- Added classic HAN-D skin.

- `1.4.6`
	- Updated Steel Mechorilla to the latest version to fix MP animation issues.
	- Updated Driver to the latest version to fix some MP bugs.
	- Added XiConstructFix (makes Xi Constructs stay closer to players)
	- Added AlignRexHurtbox (makes Rex's hurtbox sink into the floor when sprinting)

- `1.4.5`
	- Readme update.
	- Disabled Dancer by default due to suspicions of her messing with DropIn (needs testing).

- `1.4.4`
	- Added Steel Mechorilla. (Currently using default config)

- `1.4.3`
	- Added literally me.
	- Downgraded MountainCount to 0.1.0 since it's more readable.

- `1.4.2`
	- Disabled PlayableTemplar by default due to questionable coding.
	- Updated Regigigas config. Unnerfed Earth Power.

- `1.4.1`
	- Added PlayableTemplar

- `1.4.0`
	- DroneMeld
		- Fixed Emergency Drones not being affected.
	- Regigigas
		- Increased min stages to spawn from 3 -> 5
		- Increased director cost from 800 -> 1200
	- Added Dancer
	- Added ClassicItemsReturns
	- Added Forgotten Relics
		- Disabled Coil Golems
		- Disabled Hazards
		- Disabled Dry Basin
		- Disabled the hidden realm
	- Added Cooler Mithrix (Disabled by default)
	- Replaced CheatUnlocks with RealerCheatUnlocks
	
	*Adding some of the mainstays from hosts that weren't initially included in the pack.*

- `1.3.0`
	- Added Videogame Mod 2 Unofficial

- `1.2.2`
	- Added DoshDrop

- `1.2.1`
	- Added Potmobile (Disabled by default)
	- Added SafeTravelsInSkybox
	- Added GiantParticleFix
	- DroneMeld
		- Disabled "Apply to Goobo" since it's already capped at 3.
		
	*Left R2API/BepInEx unupdated, but feel free to update them if you want.*

- `1.2.0`
	- Added DroneMeld
		- Changed Settings:
			- Quantum Turrets disabled (personal perference)
			- Does not affect Squids/Beetle Guards/Zoea/Defense Nucleus/Backup Drones since these rely on strength in numbers to draw aggro.
			- No CDR/AtkSpd per stack, damage per stack increased  from 0.6 -> 1.0
				- This makes it so that drone stacks are equivalent to just having an extra drone, instead of stacking parabolically.
			
	*Originally left this out because I suspected it was causing issues with Mithrix Phase 4, but recent hosts have been using it fine and it got updated to fix a nullref.*

	- DebugToolkit
		- Regenerated config. Permission system should be set up properly by default now? Not sure.

- `1.1.0`
	- Added Regigigas (Disabled by default)
		- Pre-configured to enable the survivor version.
	- Added BlightedElites
	- Added StormyItems
		- Disabled Abyssal Talon and Charged Urchin.
	- Added AccurateEnemies
	- QueensGlandBuff
		- Regenerated config to remove unused fields.
		- Reduced damage bonus from 300% (+200%) -> 200% (+100%) since they were killing bosses too fast when stacked with RiskyMod ally changes.

- `1.0.1`
	- Expanded Other Recommended Mods section.
		- .r2z is unchanged, so no need to download this update.

- `1.0.0`
	- Release
	
</details>